cure_dep_censoring returns an object of class "dcensoring" containing the results of the fitted models.
An object of class "dcensoring" is a list containing at least the following components:
param_est a vector containing estimated parameters (dependency parameter, regression coefficients associated with the cure rate, regression coefficients associated with dependent censoring times, and time distribution parameters (Weibull or piecewise exponential)).
stde a vector containing the estimated standard errors of the estimated parameters vector.
crit a vector containing the information criteria, Akaike's information criterion (AIC), Bayesian information criterion (BIC), Hannan-Quinn information criterion (HQ), calculated according to Louis, T. A. (1982).
pvalue p-value of the estimated parameters vector.
n number of observations in the dataset.
p number of covariates associated with the cure fraction.
q number of covariates associated with the dependent censoring times (informative censoring times or competitive risk times).
formula formula used in the function call.
terms the terms object used, containing the covariates associated with the cure fraction and with the dependent censoring times.
labels1 labels of the covariates associated with the cure fraction.
labels2 labels of the covariates associated with the dependent censoring times.
risco_a_T a vector containing the cumulative baseline hazar of failure times.
risco_a_C a vector containing the cumulative baseline hazar of dependent censoring times.
bi a matrix containing the generated frailties, one of the outputs of the function cure_dep_censoring, in which the individuals are in the rows and the Monte Carlo replicas in the columns.
X_Cure a matrix of variables associated with the cure fraction.
X_C a matrix of variables associated with the dependent censoring times.
time a vector of the observable times.